/*
 * $Id: dpcap.h,v 1.5 2001/01/17 02:52:53 laik Exp $
 *
 * This file contains declarations that are global for libdpcap.
 *
 * Copyright (C) 1998 Kevin Lai
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
#ifndef __DPCAP_H__
#define __DPCAP_H__

#include <sys/time.h>
#include <netinet/ip.h>

#include "packet_capture.h"
#include "kl_version.h"

/*
 * This structure represents the packet information that goes over the
 * wire.
 */
typedef struct DPCapPacketInfo {
    struct timespec time_stamp;    /* When the packet was captured. */
    unsigned short capture_length;
    unsigned short flags;   /* PacketCaptureFlagType flags. */
    /* The packet header goes here. */
} DPCapPacketInfo;

/*
 * This is configuration information that is sent from the server to the 
 * client. These fields are all in network byte order.
 */
typedef struct DPCapServerConfig {
    uint32_t version_major;   /* Major version number */
    uint32_t version_minor;   /* Minor version number */
    uint32_t version_tertiary;/* Tertiary version number */
    uint32_t cap_len;                /* Len of data to capture from packets. */
    uint32_t clock_resolution;         /* Maximum clock resolution. */
} DPCapServerConfig;

/*
 * This is configuration information that is sent from the client to the 
 * server. These fields are all in network byte order.
 */
typedef struct DPCapClientConfig {
    uint32_t version_major;   /* Major version number */
    uint32_t version_minor;   /* Minor version number */
    uint32_t version_tertiary;/* Tertiary version number */
} DPCapClientConfig;

u_int16_t
decode_ip_cksum(const struct ip *ip);

const KLVersion *
DPCapVersionGet(void);

#endif
