/*
 * $Id: dpcap_client.h,v 1.6 2001/07/20 21:52:58 laik Exp $
 *
 * This module contains code for the libdpcap client. The client is
 * responsible for getting the packet information from the server.
 *
 * Copyright (C) 1998 Kevin Lai
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __DPCAP_CLIENT_H__
#define __DPCAP_CLIENT_H__

#include "dpcap_flow.h"

#include "kl_parse_option.h"
#include "kl_list.h"
#include "kl_event.h"

struct DPCapClient;
typedef struct DPCapClient DPCapClient;

/*
 * Called when the client has finished initialization.
 */
typedef KLException * (*DPCapClientInitFinishedFun)(void *client_data);

typedef enum DPCapClientType {
    DPCapClientTypeLive,                  /* Connect to live servers. */
    DPCapClientTypeTrace,                 /* Read from trace file. */
    DPCapClientTypeNS,                    /* Read from ns trace file. */
} DPCapClientType;

typedef struct DPCapClientLiveDef {
    const KLParseOptionServers *servers;  /* The servers to connect to. */
    const char *interface;
} DPCapClientLiveDef;

typedef struct DPCapClientTraceDef {
    KLList *file_names;                   /* The trace files to read. */
} DPCapClientTraceDef;

typedef struct DPCapClientNSDef {
    const char *file_name;                /* Trace file name. */
    const char **timers;                  /* The timers. */
} DPCapClientNSDef;

typedef struct DPCapClientDef {
    KLEventManager *manager;              /* Main event manager. */
    DPCapFlowSetDef flow_set_def;         /* Flow set definition. */
    const char *filter_cmd;               /* Filters packets. */
    int cap_len;                          /* Length of packets to capture. */
    DPCapClientType type;                 /* Type of client. */
    union {
	DPCapClientLiveDef live;
	DPCapClientTraceDef trace;
	DPCapClientNSDef ns;
    } type_data;
    int verbosity;                       /* The verbosity of status messages */
    DPCapClientInitFinishedFun init_finished;
    void *init_finished_client_data;
} DPCapClientDef;

/* Thrown when all traces are finished being read. */
KLExceptionClass DPCapClientAllTracesFinishedEC;

KLException *
DPCapClientNew(DPCapClientDef *def, DPCapClient **client_p);

void
DPCapClientDelete(DPCapClient *client);

void
DPCapClientVerify(DPCapClient *client);

#endif
