/*
 * $Id: dpcap_server.h,v 1.6 2001/07/20 21:52:58 laik Exp $
 *
 * Copyright (C) 1998 Kevin Lai
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __SERVER_H__
#define __SERVER_H__

#include "kl_event.h"

struct DPCapServer;
typedef struct DPCapServer DPCapServer;

typedef enum DPCapServerType {
    DPCapServerTypeLive,
    DPCapServerTypeTrace,
} DPCapServerType;

/*
 * Called when the server has finished initialization.
 */
typedef KLException * (*DPCapServerInitFinishedFun)(void *client_data);

typedef struct DPCapServerDef {
    KLEventManager *manager;       /* KLEvent manager. */
    const char *listen_service;    /* Port the server is listening on. */
    unsigned int send_thresh;      /* # bytes to buffer before sending. */
    struct timespec send_interval; /* Time to wait before sending. */
    const char *filter_cmd;        /* Filters packets. */
    int cap_len;                   /* Length of packets to capture. */
    int verbosity;                 /* The verbosity of status messages */
    DPCapServerInitFinishedFun init_finished;
    void *init_finished_client_data;
    DPCapServerType type;
    union {
	const char *trace_name;    /* File to read traces from. */
	const char *interface;
    } type_data;
} DPCapServerDef;

KLException *
DPCapServerNew(DPCapServerDef *def, DPCapServer **server_p);

void
DPCapServerDelete(DPCapServer *server);

#endif




