/*
 * $Id: packet_capture.h,v 1.4 2001/01/18 00:42:48 laik Exp $
 *
 * Copyright (C) 1998 Kevin Lai
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __PACKET_CAPTURE_H__
#define __PACKET_CAPTURE_H__

#include "kl_event.h"
#include "kl_exception.h"

struct PacketCapture;
typedef struct PacketCapture PacketCapture;

struct PacketCaptureFilter;
typedef struct PacketCaptureFilter PacketCaptureFilter;

/*
 * This defines the different flag bits describing packets that are passed
 * to callback functions.
 */
typedef enum PacketCaptureFlagType {
    PacketCaptureFlagArriving = 0x1,
    PacketCaptureFlagLeaving = 0x2,
    PacketCaptureFlagSource = 0x4,
    PacketCaptureFlagSourceNet = 0x8,
    PacketCaptureFlagDestination = 0x10,
    PacketCaptureFlagDestinationNet = 0x20,
} PacketCaptureFlagType;

/*
 * The immutable parts of a packet report.
 */
typedef struct PacketCaptureHeader {
    const u_int8_t *packet;            /* Original packet. */
    unsigned int capture_length;       /* Amount captured. */
    unsigned int kernel_length;        /* Amount received by kernel. */
    struct timespec time_stamp;        /* Timestamp. */
    PacketCaptureFlagType flags;       /* Flags. */
} PacketCaptureHeader;

/*
 * Functions of this type are called when a new packet arrives.
 * Returns 0 for no error, some other value for an error.
 */
typedef KLException * (*PacketCaptureNewPacketFun)(
    const u_int8_t *packet, unsigned int capture_length, 
    const PacketCaptureHeader *header, void *client_data);

typedef enum PacketCaptureType {
    PacketCaptureTypeLive,
    PacketCaptureTypeTrace,
} PacketCaptureType;

typedef struct PacketCaptureTrace {
    const char *file_name;              /* Read from this trace file. */
    KLEventHandlerFun finished_handler; /* Called when trace finishes. */
} PacketCaptureTrace;

typedef struct PacketCaptureDef {
    KLEventManager *manager;            /* KLEvent manager. */
    const char *filter_cmd;             /* Filters packets. */
    int cap_len;                        /* Capture length of packets. */
    int max_packets_capture;            /* Packets to capture in one call. */
                                        /* Callback for packet arrival. */
    PacketCaptureNewPacketFun new_packet_fun;    
    void *client_data;                  /* Client data for callback. */
    PacketCaptureType type;             /* Type of this packet capture. */
    union {
	PacketCaptureTrace trace;
	const char *interface;          /* Interface to capture from. */
    } type_data;                        /* Type dependent data. */
    int verbosity;                      /* The verbosity of status messages */
} PacketCaptureDef;

KLException *
PacketCaptureNew(PacketCaptureDef *def, PacketCapture **pcap_p);

void
PacketCaptureDelete(PacketCapture *pcap);

PacketCaptureFilter *
PacketCaptureFilterNew(PacketCapture *pcap, const char *filter_cmd);

void
PacketCaptureFilterFree(PacketCaptureFilter *filter);

int
PacketCaptureFilterFilter(
    PacketCaptureFilter *filter, const u_int8_t *buf, int kernel_len, 
    int cap_len);

#endif
